package com.uas.search.schedule;

import com.uas.search.annotation.NotEmpty;
import java.util.List;

/**
 * 管理定时任务
 * 
 * @author sunyj
 * @since 2016年12月19日 上午10:52:29
 */
public interface TaskService {
	/**
	 * 建立定时任务
	 * 
	 * @param taskInformation
	 *            定时任务的信息
	 */
	public void newTask(TaskInformation taskInformation);

	/**
	 * 根据指定的 code，移除定时任务
	 *
	 * @param code 任务的 code
	 */
	void remove(@NotEmpty("code") String code);

	/**
	 * 是否存在定时任务
	 *
	 * @param code 任务的title
	 * @return true 则存在
	 */
	boolean exist(@NotEmpty("title") String title);

	/**
	 * 获取定时任务信息
	 * 
	 * @return
	 */
	public List<TaskInformation> allTaskInformations();

	/**
	 * 开启定时任务
	 * @param taskInformation 任务名称
	 * 
	 * @return 返回的结果
	 */
	public String start(TaskInformation taskInformation);

	/**
	 * 关闭定时全部任务
	 * @return
	 */
	String stop();

	/**
	 * 关闭定时任务
	 * 
	 * @return 返回的结果
	 */
	String stop(TaskInformation taskInformation);

	/**
	 * 指定任务是否停止
	 * @param taskInformation 指定任务
	 * @return
	 */
	boolean isStopped(TaskInformation taskInformation);

	/**
	 * 所有任务是否停止
	 * @return
	 */
	boolean isStopped();

	/**
	 * 任务池是否空闲
	 * @return
	 */
	boolean isIdle();

}
