package com.uas.search.console.b2b.jms;

import com.uas.search.b2b.model.SPage;
import com.uas.search.console.b2b.util.ContextUtils;
import com.uas.search.console.b2b.util.SearchConstants;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 消息
 *
 * @author sunyj
 * @since 2017/10/11 17:33
 */
@Service
public class LuceneMessageServiceImpl implements LuceneMessageService {

    /**
     * 默认的页码
     */
    private static final int PAGE_INDEX = 1;

    /**
     * 默认每页的大小
     */
    private static final int PAGE_SIZE = 20;

    @Override
    public SPage<LuceneMessageInterface> findAll(SearchConstants.DataSourceQualifier dataSourceQualifier, Integer page, Integer size) {
        LuceneMessageDaoInterface luceneMessageDao = getLuceneMessageDao(dataSourceQualifier);
        // 处理分页信息
        if (page == null || page <= 0) {
            page = PAGE_INDEX;
        }
        if (size == null || size <= 0) {
            size = PAGE_SIZE;
        }

        SPage<LuceneMessageInterface> sPage = new SPage<>();
        long totalElement = luceneMessageDao.count();
        sPage.setTotalElement(totalElement);
        // 总数目为0，返回
        if (totalElement == 0) {
            return sPage;
        }

        int totalPage = (int) Math.ceil(totalElement / (1.0 * size));
        sPage.setTotalPage(totalPage);
        // 如果页码过大
        if (page > totalPage) {
            page = totalPage;
        }
        int start = (page - 1) * size;
        sPage.setPage(page);
        sPage.setSize(size);
        if (page == 1) {
            sPage.setFirst(true);
        }
        if (page == totalPage) {
            sPage.setLast(true);
        }

        List<LuceneMessageInterface> messages = new ArrayList<>();
        if(luceneMessageDao instanceof com.uas.search.console.b2b.jms.platformb2b.LuceneMessageDao){
            com.uas.search.console.b2b.jms.platformb2b.LuceneMessageDao dao = (com.uas.search.console.b2b.jms.platformb2b.LuceneMessageDao)luceneMessageDao;
            List<com.uas.search.console.b2b.jms.platformb2b.LuceneMessage> list = dao.findList(start, size);
            messages.addAll(list);
        }else{
            com.uas.search.console.b2b.jms.platformmanager.LuceneMessageDao dao = (com.uas.search.console.b2b.jms.platformmanager.LuceneMessageDao)luceneMessageDao;
            List<com.uas.search.console.b2b.jms.platformmanager.LuceneMessage> list = dao.findList(start, size);
            messages.addAll(list);
        }
        sPage.setContent(messages);
        return sPage;
    }

    @Override
    public LuceneMessageDaoInterface getLuceneMessageDao(SearchConstants.DataSourceQualifier dataSourceQualifier) {
        switch (dataSourceQualifier) {
            case PLATFORMB2B_DATASOURCE:
                return ContextUtils.getBean(com.uas.search.console.b2b.jms.platformb2b.LuceneMessageDao.class);
            case PLATFORMMANAGER_DATASOURCE:
                return ContextUtils.getBean(com.uas.search.console.b2b.jms.platformmanager.LuceneMessageDao.class);
            default:
                throw new IllegalArgumentException("Unsupported datasource qualifier: " + dataSourceQualifier);
        }
    }

}
