package com.uas.search.console.b2b.model;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

/**
 * 买家的应付发票
 * 
 * @author suntg
 * 
 */
@Table(name = PurchaseApbillSimpleInfo.TABLE_NAME)
@Entity
public class PurchaseApbillSimpleInfo {

	/**
	 * 表名
	 */
	// 每个主表必须与com.uas.search.b2b.service.SearchService.Table_name对应的单据类型的value保持一致
	public static final String TABLE_NAME = "PURC$APBILL";

	/**
	 * 各字段列名（也是存储索引时的field名）
	 */
	public static final String ID_FIELD = "pab_id";

	public static final String CODE_FIELD = "pab_code";

	public static final String DATE_FIELD = "pab_date";

	public static final String ENTERPRISE_FIELD = "pad_enuu";

	public static final String VEND_FIELD = "pad_venduu";

	public static final String ITEMS_FIELD = "papi_papid";

	@Id
	@Column(name = ID_FIELD)
	private Long id;

	/**
	 * 单号
	 */
	@Column(name = CODE_FIELD)
	private String code;

	/**
	 * 日期
	 */
	@Column(name = DATE_FIELD)
	private Date date;

	/**
	 * 客户企业UU
	 */
	@OneToOne
	@JoinColumn(name = ENTERPRISE_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo enterprise;

	/**
	 * 供应商企业UU（登录的本企业）
	 */
	@OneToOne
	@JoinColumn(name = VEND_FIELD, insertable = false, updatable = false)
	private EnterpriseSimpleInfo vend;

	/**
	 * 验收明细
	 */
	@OneToMany(cascade = { CascadeType.ALL }, fetch = FetchType.EAGER)
	@JoinColumn(name = ITEMS_FIELD, updatable = false, insertable = false)
	private Set<PurchaseApBillItemSimpleInfo> items;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public Date getDate() {
		return date;
	}

	public void setDate(Date date) {
		this.date = date;
	}

	public EnterpriseSimpleInfo getEnterprise() {
		return enterprise;
	}

	public void setEnterprise(EnterpriseSimpleInfo enterprise) {
		this.enterprise = enterprise;
	}

	public EnterpriseSimpleInfo getVend() {
		return vend;
	}

	public void setVend(EnterpriseSimpleInfo vend) {
		this.vend = vend;
	}

	public Set<PurchaseApBillItemSimpleInfo> getItems() {
		return items;
	}

	public void setItems(Set<PurchaseApBillItemSimpleInfo> items) {
		this.items = items;
	}

	/**
	 * 获取所有可以搜索的字段列名（索引的field名）
	 * 
	 * @return 可以搜索的字段列名
	 */
	public static List<String> getKeywordFields() {
		List<String> fields = new ArrayList<>();
		fields.add(CODE_FIELD);
		fields.add(ENTERPRISE_FIELD);
		fields.add(ITEMS_FIELD);
		return fields;
	}

	@Override
	public String toString() {
		return "PurchaseApbillSimpleInfo [id=" + id + ", code=" + code + ", date=" + date + ", enterprise=" + enterprise
				+ ", vend=" + vend + ", items=" + items + "]";
	}

}
